@@ -1,18 +1,16 @@
 from PIL import Image, ImageDraw, ImageFont
-from filehandling import join_path
-from omnitools import color_value, textbox
+from omnitools import color_value, textbox, join_path
 import os
 
 
-__ALL__ = ["TextToPng"]
-
-
-class TextToPng(object):
-    def __init__(self, font_size: int, font_file: str = None,
-                 background_color: color_value = (0, 0, 0),
-                 text_color: color_value = (255, 255, 255),
-                 save_dir: str = os.environ["TEMP"]) -> None:
-        self.font_file = font_file or os.path.join(os.path.dirname(os.path.abspath(__file__)), "mingliu.ttc")
+class text2png:
+    def __init__(
+            self, font_size: int, font_file: str = None,
+            background_color: color_value = (0, 0, 0),
+            text_color: color_value = (255, 255, 255),
+            save_dir: str = os.environ["TEMP"]
+    ):
+        self.font_file = font_file or os.path.join(os.path.dirname(os.path.abspath(__file__)), "pkg_data.ttc")
         self.font_size = font_size
         self.background_color = background_color
         self.text_color = text_color
